@@ -1,5 +1,5 @@
 
--- libquvi-scripts v0.4.6
+-- libquvi-scripts v0.4.7
 -- Copyright (C) 2012  Mikhail Gusarov <dottedmag@dottedmag.net>
 --
 -- This file is part of libquvi-scripts <http://quvi.sourceforge.net/>.
@@ -29,7 +29,7 @@ function ident(self)
     r.formats    = "default"
     r.categories = C.proto_http
     local U      = require 'quvi/util'
-    r.handles    = U.handles(self.page_url, {r.domain}, {"/teleshow/"})
+    r.handles    = U.handles(self.page_url, {r.domain}, {"/articles/"})
     return r
 end
 
@@ -43,6 +43,9 @@ end
 function parse(self)
     self.host_id = "tvrain"
 
+    self.id = self.page_url:match('%-(%d+)/$')
+                or error("no match: media ID")
+
     local p = quvi.fetch(self.page_url)
 
     -- tvrain uses <iframe> for the video player which constructs URL to load a
@@ -61,9 +64,6 @@ function parse(self)
 
     local pl = quvi.fetch(u, {fetch_type='playlist'})
 
-    self.id = pl:match('<programm[^>]-id="(.-)"')
-                or error("no match: media ID")
-
     self.title = pl:match('<video[^>]-name="(.-)"')
                   or error("no match: media title")
 
